rai\_toolbox.datasets.ImageNetM10
=================================

.. currentmodule:: rai_toolbox.datasets

.. autoclass:: ImageNetM10

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ImageNetM10.__init__
   
   

   
   
   